@@ -1,4 +1,5 @@
-"cmh.test" = function(x){
+`cmh.test` <-
+function(x){
 
  pooled = apply(x,1:2,sum)
  OR = pooled[1,1] * pooled[2,2] / pooled[1,2] / pooled[2,1]
@@ -38,3 +39,4 @@
 structure(list(parameter = PARAMETER, method = METHOD, data.name = DNAME), class = "htest")
     
 }
+
